# Description

Ce depot montre comment réaliser un traceur à partir de l'ensemble LEGO Boost 17101. Il comprend :
- Les instructions de montage du modèle : [`docs/building_instructions`](https://github.com/valentin-burillier/spiderpen/blob/main/docs/building_instructions.pdf)
- La librairie python permettant le contrôle du robot : [`spiderpen`](https://github.com/valentin-burillier/spiderpen/tree/main/spiderpen)
- des exemples d'utilisation : [`examples`](https://github.com/valentin-burillier/spiderpen/tree/main/examples)
- toute la documentation nécessaire : [`docs`](https://github.com/valentin-burillier/spiderpen/tree/main/docs)

[photo robot]

Pour rendre le pilotage du robot simple et accessible à tout le monde, le codage des déplacements se fait à la manière turtle [`docs/docs`](https://github.com/valentin-burillier/spiderpen/blob/main/docs/docs.md)

# Examples

à faire

# Installation

[trouver comment mettre le package sur pip]

# TODO

- docstring
- rédiger le fichier documentant le fonctionnement de l'algorithme de déplacement
- mettre des exemples d'utilisation
- corriger les fautes d'orthographes et angliser le tout

# Links

- https://www.youtube.com/watch?v=HU9SaCFnCng / https://www.youtube.com/watch?v=5x0n29MjIi8 - les videos qui ont inspiré ce répertoire
- https://github.com/undera/pylgbst - la librairie permettant le controle du Hub
